API Documentation
=================

The central portal to all Matchlight features is through the Matchlight
connection object. We always assign the Matchlight connection object to the
name `ml`. This is used throughout this documentation and the tutorial.

Matchlight
##########

.. autoclass:: matchlight.Matchlight
   :members:


Fingerprint Monitoring
######################

.. _projectmethods:

Project Methods
***************

.. autoclass:: matchlight.project.ProjectMethods
   :members:

.. _recordmethods:

Record Methods
**************

.. autoclass:: matchlight.record.RecordMethods
   :members:

.. _alertmethods:

Alert Methods
**************

.. autoclass:: matchlight.alert.AlertMethods
   :members:

.. _feedmethods:

Data Feeds
##########

Feed Methods
************

.. autoclass:: matchlight.feed.FeedMethods
   :members:


Retrospective Search
####################

.. _searchmethods:

Search Methods
**************

.. autoclass:: matchlight.search.SearchMethods
   :members:


Matchlight Objects
##################

Project
*******

.. autoclass:: matchlight.Project
   :members:


Record
******

.. autoclass:: matchlight.Record
   :members:

Alert
******

.. autoclass:: matchlight.Alert
   :members:

Feed
****

.. autoclass:: matchlight.Feed
    :members:
